@@ -3,7 +3,6 @@
  * Summary: common macros and enums for the libvirt and libvirt-admin library
  * Description: Provides common macros and enums needed by both libvirt and
  *              libvirt-admin libraries
- * Author: Erik Skultety <eskultet@redhat.com>
  *
  * Copyright (C) 2015 Red Hat, Inc.
  *
@@ -49,7 +48,7 @@ extern "C" {
 #   define VIR_EXPORT_VAR extern
 #  else
 #   ifdef IN_LIBVIRT
-#    define VIR_EXPORT_VAR __declspec(dllexport)
+#    define VIR_EXPORT_VAR __declspec(dllexport) extern
 #   else
 #    define VIR_EXPORT_VAR __declspec(dllimport) extern
 #   endif
@@ -73,7 +72,7 @@ extern "C" {
  * version * 1,000,000 + minor * 1000 + micro
  */
 
-# define LIBVIR_VERSION_NUMBER 1003005
+# define LIBVIR_VERSION_NUMBER 6006000
 
 /**
  * LIBVIR_CHECK_VERSION:
